AndroidInfo class
Properties
-
applicationId
→ String
-
The Android application ID (package name).
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sha256
→ List<String>
-
List of release SHA-256 keys
Ensure that the app opens directly from the link if already installed.
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap()
→ Map<String, dynamic>
-
Map representation of the model
-
toString()
→ String
-
A string representation of this object.
inherited