applicationId property

String applicationId
final

The Android application ID (package name).

This ID is used to construct the Play Store URL: https://play.google.com/store/apps/details?id=<applicationId>. If the app is not installed on the device, this URL is used to redirect users to the Play Store for downloading the app.

Implementation

final String applicationId;