IOSInfo class

Constructors

IOSInfo({required String teamId, required String bundleId, required String appStoreURL})
iOS-specific data

Properties

appStoreURL String
The App Store download URL of your app.
If your app is not live yet, you can still find the app ID in the App Information section in App Store Connect.
Your appStoreURL will then be https://apps.apple.com/app/id{app_id}. Provide an empty string if you don't have an App Store account yet.
final
bundleId String
Bundle Id
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
teamId String
Your Apple Team ID.
Ensures the app opens from the link if already installed.
Provide an empty string if you don't have an App Store account yet.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Map representation of the model
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited