teamId property
Your Apple Team ID.
Ensures the app opens from the link if already installed.
Provide an empty string if you don't have an App Store account yet.
Implementation
final String teamId;
Your Apple Team ID.
Ensures the app opens from the link if already installed.
Provide an empty string if you don't have an App Store account yet.
final String teamId;