imageURL property
An image URL for link preview, typically an App Logo Make sure to disable CORS for deeplynks.web.app to allow access
Implementation
final String? imageURL;
An image URL for link preview, typically an App Logo Make sure to disable CORS for deeplynks.web.app to allow access
final String? imageURL;