AndroidInfo class

Constructors

AndroidInfo({required String applicationId, required List<String> sha256})
Android-specific data

Properties

applicationId String
Application Id (Package Name)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sha256 List<String>
List of release SHA-256 keys
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Map representation of the model
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited