LinkModel class
Properties
-
customLink
→ String?
-
Link created with your custom branded domain
final
-
defaultLink
→ String
-
Link created with our new default host
urlynk.in
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
oldLink
→ String?
-
Link created with our old default host
deeplynks.web.app
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited