MetaInfo class
Properties
-
description
→ String?
-
A short description of the app.
Used in link previews. Must be 150 characters or fewer if provided.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
imageURL
→ String?
-
An image URL for link preview, typically an app logo.
Ensure that CORS is disabled for urlynk.in
final
-
name
→ String
-
The display name of the app.
This will be used in link previews. Must be 50 characters or fewer.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap()
→ Map<String, dynamic>
-
Map representation of the model
-
toString()
→ String
-
A string representation of this object.
inherited