MetaInfo class

App Meta Data This data will be used for link preview

Constructors

MetaInfo({String? imageURL, required String name, required String description})

Properties

description String
App description
final
hashCode int
The hash code for this object.
no setterinherited
imageURL String?
An image URL for link preview, typically an App Logo Make sure to disable CORS for deeplynks.web.app to allow access
final
name String
App name
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Map representation of the model
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited